@@ -10,9 +10,9 @@
 #
 #
 "K2" <-
-function(S=35,T=25,P=0,k1k2='l'){
+function(S=35,T=25,P=0,k1k2='l',pHscale="T"){
 
-nK <- max(length(S), length(T), length(P), length(k1k2))
+nK <- max(length(S), length(T), length(P), length(k1k2), length(pHscale))
 
 ##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
 
@@ -20,6 +20,7 @@ if(length(S)!=nK){S <- rep(S[1], nK)}
 if(length(T)!=nK){T <- rep(T[1], nK)}
 if(length(P)!=nK){P <- rep(P[1], nK)}
 if(length(k1k2)!=nK){k1k2 <- rep(k1k2[1], nK)}
+if(length(pHscale)!=nK){pHscale <- rep(pHscale[1], nK)}
 
 
 #-------Constantes----------------
@@ -127,8 +128,18 @@ if (P[i] > 0.0)
 }
 }
 
+###----------------pH scale corrections
+factor <- rep(NA,nK)
+pHsc <- rep(NA,nK)
+for(i in (1:nK)){   
+ if(pHscale[i]=="T"){factor[i] <- 1 ; pHsc[i] <- "total scale"}
+ if(pHscale[i]=="F"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2free ; pHsc[i] <- "free scale"}
+ if(pHscale[i]=="SWS"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2SWS ; pHsc[i] <- "seawater scale"}
+K2[i] <- K2[i]*factor[i]
+}
+
 attr(K2,"unit")     = "mol/kg-soln"
-attr(K2,"pH scale") = "total hydrogen ion concentration"
+attr(K2,"pH scale") = pHsc
 return(K2)
 }
 
